/* 
 *   $Id: ad_hfs.h,v 1.1.1.1 2000/09/06 20:01:54 jsquyres Exp $    
 *
 *   Copyright (C) 1997 University of Chicago. 
 *   See COPYRIGHT notice in top-level directory.
 */

#ifndef AD_HFS_INCLUDE
#define AD_HFS_INCLUDE

#include <unistd.h>
#include <sys/types.h>
#include <fcntl.h>
#include "adio.h"
#ifdef SPPUX
#  include <sys/cnx_types.h>
#  include <sys/puio.h>
#  include <cnx_unistd.h>
#endif

#endif
